@@ -6,13 +6,20 @@ class LambdaFunction:
         self.name = name
         self.client = boto3.client('lambda',region_name=region)
 
-    def deploy(self, S3bucket,S3key):
+    def deploy_zip(self, S3bucket,S3key):
         print("Deploying function: {}".format(self.name))
         self.client.update_function_code(
             FunctionName=self.name,
             S3Bucket=S3bucket,
             S3Key=S3key
         ) 
+    def deploy_image(self, image_uri):
+        print("Deploying function: {}".format(self.name))
+        self.client.update_function_code(
+            FunctionName=self.name,
+            ImageUri=image_uri
+        ) 
+        self.wait_until_its_updated()
 
     def update_alias(self,alias,description, version):
         print("Updating alias: {}".format(alias))
@@ -50,4 +57,10 @@ class LambdaFunction:
             Environment = {
                 "Variables": variables
             }
+        )
+    
+    def wait_until_its_updated(self):
+        waiter = self.client.get_waiter('function_updated')
+        waiter.wait(
+            FunctionName=self.name,
         )
\ No newline at end of file
